package com.fs.gtPush.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.fs.gtPush.domain.UniPushLog;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * uni推送消息记录Mapper接口
 *
 * @author fs
 * @date 2025-03-12
 */
public interface PushLogMapper extends BaseMapper<UniPushLog>{
    /**
     * 查询uni推送消息记录
     *
     * @param id uni推送消息记录主键
     * @return uni推送消息记录
     */
    UniPushLog selectPushLogById(String id);

    /**
     * 查询uni推送消息记录列表
     *
     * @param UniPushLog uni推送消息记录
     * @return uni推送消息记录集合
     */
    List<UniPushLog> selectPushLogList(UniPushLog UniPushLog);

    /**
     * 新增uni推送消息记录
     *
     * @param UniPushLog uni推送消息记录
     * @return 结果
     */
    int insertPushLog(UniPushLog UniPushLog);

    /**
     * 修改uni推送消息记录
     *
     * @param UniPushLog uni推送消息记录
     * @return 结果
     */
    int updatePushLog(UniPushLog UniPushLog);

    /**
     * 删除uni推送消息记录
     *
     * @param id uni推送消息记录主键
     * @return 结果
     */
    int deletePushLogById(String id);

    /**
     * 批量删除uni推送消息记录
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deletePushLogByIds(String[] ids);

    UniPushLog getLast(@Param("userId") Long userId);

    Integer getNumByIsRead(@Param("userId") Long userId);

    Integer setIsRead(@Param("logIds")List<Long> logIds,@Param("userId") Long userId);
}
